@@ -160,9 +160,9 @@ def batch_download(
 
     path = Path(file_path)
     if path.is_dir():
-        file_obj = zip_dir(source_dir=path.parent)
+        file_obj = zip_dir(source_dir=path)
         response = StreamingResponse(file_obj, media_type="application/octet-stream")
-        response.headers["Content-Disposition"] = f'attachment; filename="{batch_id}_{file_id}.zip"'
+        response.headers["Content-Disposition"] = f'attachment; filename="{batch_id}.zip"'
     else:
         response = FileResponse(
             str(path.absolute()),
